/*-
 * Copyright (c) 2000 George C A Reid <greid@ukug.uk.freebsd.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer
 *    in this position and unchanged.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * $Id: plasma_saver.h,v 1.2 2001/01/24 16:56:49 greid Exp $
 * $FreeBSD$
 */

#define PI		3.14159265358979323846
#define TWO_PI		6.28318530717958647692

/* Precomputed values of sin(x), 0<=x<=TWO_PI */

float aprsinv[] = 	{	0.0000, 0.0698, 0.1392, 0.2079, 0.2756,
				0.3420,	0.4067, 0.4695, 0.5299, 0.5878,
				0.6428,	0.6947, 0.7431, 0.7880, 0.8290,
				0.8660,	0.8988, 0.9272, 0.9511, 0.9703,
				0.9848,	0.9945, 0.9994, 0.9994, 0.9945,
				0.9848,	0.9703, 0.9511, 0.9272, 0.8988,
				0.8660,	0.8290, 0.7880, 0.7431, 0.6947,
				0.6428,	0.5878, 0.5299, 0.4695, 0.4067,
				0.3420,	0.2756, 0.2079, 0.1392, 0.0698,
				0.0000,	-0.0698, -0.1392, -0.2079, -0.2756,
				-0.3420,-0.4067, -0.4695, -0.5299, -0.5878,
				-0.6428,-0.6947, -0.7431, -0.7880, -0.8290,
				-0.8660,-0.8988, -0.9272, -0.9511, -0.9703,
				-0.9848,-0.9945, -0.9994, -0.9994, -0.9945,
				-0.9848,-0.9703, -0.9511, -0.9272, -0.8988,
				-0.8660,-0.8290, -0.7880, -0.7431, -0.6947,
				-0.6428,-0.5878, -0.5299, -0.4695, -0.4067,
				-0.3420,-0.2756, -0.2079, -0.1392, -0.0698
			};

u_char plasma_pal[768] = {
		0,	0,	0,
		0,	0,	0x80,
		0x80,	0,	0,
		0x80,	0,	0x80,
		0,	0x80,	0,
		0,	0x80,	0x80,
		0x80,	0x80,	0,
		0xc0,	0xc0,	0xc0,
		0x60,	0x58,	0x78,
		0x98,	0x90,	0xa8,
		0,	0xa8,	0,
		0xa8,	0,	0,
		0xa8,	0xa8,	0,
		0,	0,	0xa8,
		0,	0xa8,	0xa8,
		0x54,	0,	0xa8,
		0xa8,	0xa8,	0xa8,
		0x54,	0x54,	0x54,
		0x54,	0xfc,	0x54,
		0xfc,	0x54,	0x54,
		0xfc,	0xfc,	0x54,
		0x54,	0x54,	0xfc,
		0x54,	0xfc,	0xfc,
		0xfc,	0x54,	0xfc,
		0xfc,	0xfc,	0xfc,
		0x17,	0x17,	0x4f,
		0x17,	0x17,	0x4f,
		0x1b,	0x1b,	0x53,
		0x1b,	0x1b,	0x57,
		0x1f,	0x1f,	0x5b,
		0x1f,	0x1f,	0x5f,
		0x23,	0x23,	0x63,
		0x27,	0x27,	0x63,
		0x27,	0x27,	0x67,
		0x2b,	0x2b,	0x6b,
		0x2f,	0x2f,	0x6f,
		0x2f,	0x2f,	0x73,
		0x33,	0x33,	0x73,
		0x37,	0x37,	0x77,
		0x3b,	0x3b,	0x7b,
		0x3b,	0x3b,	0x7f,
		0x3f,	0x3f,	0x83,
		0x43,	0x43,	0x83,
		0x47,	0x47,	0x87,
		0x4b,	0x4b,	0x8b,
		0x4f,	0x4f,	0x8f,
		0x53,	0x53,	0x93,
		0x57,	0x57,	0x97,
		0x5b,	0x5b,	0x97,
		0x5f,	0x5f,	0x9b,
		0x63,	0x63,	0x9f,
		0x67,	0x67,	0xa3,
		0x6b,	0x6b,	0xa7,
		0x6f,	0x6f,	0xa7,
		0x73,	0x73,	0xab,
		0x77,	0x77,	0xaf,
		0x7b,	0x7b,	0xb3,
		0x7f,	0x7f,	0xb7,
		0x87,	0x87,	0xbb,
		0x8b,	0x8b,	0xbb,
		0x8f,	0x8f,	0xbf,
		0x93,	0x93,	0xc3,
		0x9b,	0x9b,	0xc7,
		0x9f,	0x9f,	0xcb,
		0xa3,	0xa3,	0xcb,
		0xa7,	0xa7,	0xcf,
		0xaf,	0xaf,	0xd3,
		0xb3,	0xb3,	0xd7,
		0xbb,	0xbb,	0xdb,
		0xbf,	0xbf,	0xdb,
		0xc7,	0xc7,	0xdf,
		0xcb,	0xcb,	0xe3,
		0xcf,	0xcf,	0xe7,
		0xd7,	0xd7,	0xeb,
		0xdf,	0xdf,	0xef,
		0xe3,	0xe3,	0xef,
		0xe7,	0xe7,	0xf3,
		0xef,	0xef,	0xf7,
		0xf7,	0xf7,	0xfb,
		0xff,	0xff,	0xff,
		0xf7,	0xf7,	0xf3,
		0xf3,	0xef,	0xe7,
		0xef,	0xe7,	0xdf,
		0xeb,	0xdf,	0xd7,
		0xe7,	0xd7,	0xcf,
		0xe3,	0xd3,	0xc3,
		0xdf,	0xcb,	0xbb,
		0xd7,	0xc3,	0xb3,
		0xd3,	0xbf,	0xab,
		0xcf,	0xb7,	0xa3,
		0xcb,	0xb3,	0x9b,
		0xc7,	0xab,	0x93,
		0xc3,	0xa3,	0x8b,
		0xbf,	0x9f,	0x87,
		0xb7,	0x97,	0x7f,
		0xb3,	0x93,	0x77,
		0xaf,	0x8b,	0x6f,
		0xab,	0x87,	0x6b,
		0xa7,	0x83,	0x63,
		0xa3,	0x7b,	0x5b,
		0x9f,	0x77,	0x57,
		0x97,	0x6f,	0x53,
		0x93,	0x6b,	0x4b,
		0x8f,	0x67,	0x47,
		0x8b,	0x63,	0x3f,
		0x87,	0x5f,	0x3b,
		0x83,	0x57,	0x37,
		0x7f,	0x53,	0x33,
		0x77,	0x4f,	0x2f,
		0x73,	0x4b,	0x2b,
		0x6f,	0x47,	0x27,
		0x6b,	0x43,	0x23,
		0x67,	0x3f,	0x1f,
		0x63,	0x3b,	0x1b,
		0x5f,	0x37,	0x17,
		0x57,	0x33,	0x13,
		0x53,	0x2f,	0xf,
		0x4f,	0x2b,	0xf,
		0x4b,	0x27,	0xb,
		0x47,	0x23,	0xb,
		0x43,	0x23,	0x7,
		0x3f,	0x1f,	0x7,
		0x37,	0x1b,	0x7,
		0x33,	0x17,	0,
		0x2f,	0x17,	0,
		0x2b,	0x13,	0,
		0x27,	0xf,	0,
		0x23,	0xf,	0,
		0x23,	0xf,	0,
		0x27,	0xf,	0,
		0x2b,	0xf,	0,
		0x2f,	0xf,	0,
		0x33,	0x13,	0,
		0x37,	0x13,	0,
		0x3b,	0x13,	0,
		0x3b,	0x13,	0x7,
		0x3f,	0x13,	0x7,
		0x43,	0x13,	0x7,
		0x47,	0x13,	0x7,
		0x4b,	0x13,	0xb,
		0x4f,	0x17,	0xb,
		0x53,	0x17,	0xb,
		0x57,	0x17,	0xf,
		0x57,	0x17,	0xf,
		0x5b,	0x17,	0x13,
		0x5f,	0x17,	0x13,
		0x63,	0x17,	0x17,
		0x67,	0x17,	0x1b,
		0x6b,	0x1b,	0x1f,
		0x6f,	0x1f,	0x23,
		0x6f,	0x1f,	0x27,
		0x73,	0x23,	0x2b,
		0x77,	0x27,	0x2f,
		0x7b,	0x27,	0x33,
		0x7f,	0x2b,	0x37,
		0x83,	0x2f,	0x3f,
		0x87,	0x2f,	0x43,
		0x87,	0x33,	0x47,
		0x8b,	0x37,	0x4b,
		0x8f,	0x3b,	0x53,
		0x93,	0x3b,	0x57,
		0x97,	0x43,	0x5b,
		0x9b,	0x43,	0x63,
		0x9f,	0x47,	0x67,
		0x9f,	0x4b,	0x6b,
		0xa3,	0x4f,	0x73,
		0xa7,	0x53,	0x77,
		0xab,	0x57,	0x7f,
		0xaf,	0x5b,	0x83,
		0xb3,	0x5f,	0x87,
		0xb7,	0x63,	0x8f,
		0xb7,	0x67,	0x93,
		0xbb,	0x6b,	0x9b,
		0xbf,	0x6f,	0x9f,
		0xc3,	0x77,	0xa7,
		0xc7,	0x7b,	0xab,
		0xcb,	0x7f,	0xaf,
		0xcf,	0x83,	0xb7,
		0xcf,	0x87,	0xbb,
		0xd3,	0x8f,	0xc3,
		0xd7,	0x93,	0xc7,
		0xdb,	0x97,	0xcb,
		0xdf,	0x9f,	0xd3,
		0xe3,	0xa3,	0xd7,
		0xe7,	0xa7,	0xdb,
		0xe7,	0xaf,	0xdf,
		0xeb,	0xb3,	0xe7,
		0xef,	0xbb,	0xeb,
		0xf3,	0xbf,	0xef,
		0xf7,	0xc3,	0xf3,
		0xfb,	0xcb,	0xfb,
		0xff,	0xd3,	0xff,
		0xfb,	0xe7,	0xf7,
		0xf7,	0xdf,	0xf3,
		0xf3,	0xd7,	0xef,
		0xef,	0xd3,	0xeb,
		0xeb,	0xcb,	0xe3,
		0xe7,	0xc3,	0xdb,
		0xe3,	0xbf,	0xd7,
		0xdf,	0xb7,	0xcf,
		0xdb,	0xaf,	0xc7,
		0xdb,	0xab,	0xbf,
		0xd7,	0xa3,	0xb7,
		0xd3,	0x9f,	0xaf,
		0xcf,	0x97,	0xa7,
		0xcb,	0x93,	0x9f,
		0xc7,	0x8f,	0x97,
		0xc3,	0x87,	0x8f,
		0xbf,	0x83,	0x87,
		0xbb,	0x7f,	0x7f,
		0xb7,	0x7b,	0x77,
		0xb7,	0x7b,	0x73,
		0xb3,	0x77,	0x6f,
		0xaf,	0x77,	0x67,
		0xab,	0x77,	0x63,
		0xa7,	0x77,	0x5f,
		0xa3,	0x77,	0x5b,
		0x9f,	0x73,	0x57,
		0x9b,	0x73,	0x53,
		0x97,	0x77,	0x4f,
		0x93,	0x77,	0x4b,
		0x8f,	0x77,	0x47,
		0x8f,	0x77,	0x43,
		0x8b,	0x77,	0x3f,
		0x87,	0x77,	0x3b,
		0x83,	0x77,	0x37,
		0x7f,	0x77,	0x33,
		0x7b,	0x77,	0x2f,
		0x77,	0x77,	0x2b,
		0x6f,	0x73,	0x2b,
		0x67,	0x6f,	0x27,
		0x5f,	0x6b,	0x23,
		0x57,	0x6b,	0x1f,
		0x53,	0x67,	0x1f,
		0x4b,	0x63,	0x1b,
		0x43,	0x5f,	0x17,
		0x3b,	0x5b,	0x17,
		0x37,	0x57,	0x13,
		0x2f,	0x53,	0x13,
		0x27,	0x4f,	0xf,
		0x23,	0x4b,	0xf,
		0x1b,	0x47,	0xb,
		0x17,	0x43,	0xb,
		0x13,	0x43,	0x7,
		0xf,	0x3f,	0x7,
		0x7,	0x3b,	0x7,
		0x7,	0x37,	0x7,
		0x7,	0x33,	0x7,
		0,	0x2f,	0x7,
		0,	0x2b,	0x7,
		0,	0x27,	0x7,
		0,	0x23,	0xb,
		0,	0x1f,	0xb,
		0,	0x1f,	0xb,
		0,	0x1b,	0xb,
		0xff,	0xff,	0xff
	};
